package pages

import (
	"fmt"
	"os"

	"github.com/gofiber/fiber/v2"

	"github.com/sethvargo/go-password/password"

	"github.com/containrrr/shoutrrr"
)

// SignupPage is the signup page handler
func SignupPage(c *fiber.Ctx) error {
	username := c.FormValue("username")
	email := c.FormValue("email")
	if username == "" || email == "" {
		return c.SendStatus(fiber.StatusBadRequest)
	}

	// generate password
	pass, err := password.Generate(30, 10, 10, false, false)
	if err != nil {
		return c.SendStatus(fiber.StatusInternalServerError)
	}

	// send notification to admins
	err = shoutrrr.Send(os.Getenv("PUBLAPI_SHOUTRRRURL"), "New user signup! Please review /var/publapi/users/"+username+".sh to approve or deny the user.")
	if err != nil {
		return c.SendStatus(fiber.StatusInternalServerError)
	}

	// create user file
	f, err := os.Create("/var/publapi/users/" + username + ".sh")
	if err != nil {
		return c.SendStatus(fiber.StatusInternalServerError)
	}
	defer f.Close()

	bashscript := "#!/bin/bash \n" +
		"# Path: /var/publapi/users/.sh\n" +
		"# This file is generated by publapi. Do not edit this file.\n" +
		"useradd -m -s /bin/bash " + username + "\n" +
		"echo " + username + " created!"

	fmt.Println(bashscript)

	// write to file
	_, err = f.WriteString(bashscript)
	if err != nil {
		return c.SendStatus(fiber.StatusInternalServerError)
	}

	return c.JSON(fiber.Map{
		"username": username,
		"pass":     pass,
		"message":  "User created! Please allow us 24 hours or more to review your account.",
		"status":   c.Response().StatusCode(),
	})

}
